@@ -20,6 +20,7 @@
 #include <ags/X/editor/ags_ramp_acceleration_dialog.h>
 #include <ags/X/editor/ags_ramp_acceleration_dialog_callbacks.h>
 
+#include <ags/X/ags_ui_provider.h>
 #include <ags/X/ags_window.h>
 #include <ags/X/ags_automation_window.h>
 #include <ags/X/ags_automation_editor.h>
@@ -401,9 +402,13 @@ ags_ramp_acceleration_dialog_get_property(GObject *gobject,
 void
 ags_ramp_acceleration_dialog_connect(AgsConnectable *connectable)
 {
-  AgsAutomationEditor *automation_editor;
+  AgsWindow *window;
   AgsRampAccelerationDialog *ramp_acceleration_dialog;
 
+  AgsApplicationContext *application_context;
+  
+  gboolean use_composite_editor;
+  
   ramp_acceleration_dialog = AGS_RAMP_ACCELERATION_DIALOG(connectable);
 
   if((AGS_RAMP_ACCELERATION_DIALOG_CONNECTED & (ramp_acceleration_dialog->flags)) != 0){
@@ -412,7 +417,12 @@ ags_ramp_acceleration_dialog_connect(AgsConnectable *connectable)
 
   ramp_acceleration_dialog->flags |= AGS_RAMP_ACCELERATION_DIALOG_CONNECTED;
 
-  automation_editor = AGS_WINDOW(ramp_acceleration_dialog->main_window)->automation_window->automation_editor;
+  /* application context */
+  application_context = ags_application_context_get_instance();
+
+  use_composite_editor = ags_ui_provider_use_composite_editor(AGS_UI_PROVIDER(application_context));
+  
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   
   g_signal_connect(ramp_acceleration_dialog, "response",
 		   G_CALLBACK(ags_ramp_acceleration_dialog_response_callback), ramp_acceleration_dialog);
@@ -421,16 +431,33 @@ ags_ramp_acceleration_dialog_connect(AgsConnectable *connectable)
 		   G_CALLBACK(ags_ramp_acceleration_dialog_port_callback), ramp_acceleration_dialog);
 
   /* machine changed */
-  g_signal_connect_after(automation_editor, "machine-changed",
-			 G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback), ramp_acceleration_dialog);
+  if(use_composite_editor){
+     AgsCompositeEditor *composite_editor;
+    
+    composite_editor = window->composite_editor;
+    
+    g_signal_connect_after(composite_editor, "machine-changed",
+			   G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback), ramp_acceleration_dialog);
+  }else{
+    AgsAutomationEditor *automation_editor;
+    
+    automation_editor = window->automation_window->automation_editor;
+    
+    g_signal_connect_after(automation_editor, "machine-changed",
+			   G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback), ramp_acceleration_dialog);
+  }
 }
 
 void
 ags_ramp_acceleration_dialog_disconnect(AgsConnectable *connectable)
 {
-  AgsAutomationEditor *automation_editor;
+  AgsWindow *window;
   AgsRampAccelerationDialog *ramp_acceleration_dialog;
 
+  AgsApplicationContext *application_context;
+  
+  gboolean use_composite_editor;
+
   ramp_acceleration_dialog = AGS_RAMP_ACCELERATION_DIALOG(connectable);
 
   if((AGS_RAMP_ACCELERATION_DIALOG_CONNECTED & (ramp_acceleration_dialog->flags)) == 0){
@@ -439,8 +466,13 @@ ags_ramp_acceleration_dialog_disconnect(AgsConnectable *connectable)
 
   ramp_acceleration_dialog->flags &= (~AGS_RAMP_ACCELERATION_DIALOG_CONNECTED);
 
-  automation_editor = AGS_WINDOW(ramp_acceleration_dialog->main_window)->automation_window->automation_editor;
+  /* application context */
+  application_context = ags_application_context_get_instance();
 
+  use_composite_editor = ags_ui_provider_use_composite_editor(AGS_UI_PROVIDER(application_context));
+  
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+  
   g_object_disconnect(G_OBJECT(ramp_acceleration_dialog),
 		      "any_signal::response",
 		      G_CALLBACK(ags_ramp_acceleration_dialog_response_callback),
@@ -453,11 +485,28 @@ ags_ramp_acceleration_dialog_disconnect(AgsConnectable *connectable)
 		      ramp_acceleration_dialog,
 		      NULL);
 
-  g_object_disconnect(G_OBJECT(automation_editor),
-		      "any_signal::machine-changed",
-		      G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback),
-		      ramp_acceleration_dialog,
-		      NULL);
+  /* machine changed */
+  if(use_composite_editor){
+     AgsCompositeEditor *composite_editor;
+    
+    composite_editor = window->composite_editor;
+    
+    g_object_disconnect(G_OBJECT(composite_editor),
+			"any_signal::machine-changed",
+			G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback),
+			ramp_acceleration_dialog,
+			NULL);
+  }else{
+    AgsAutomationEditor *automation_editor;
+    
+    automation_editor = window->automation_window->automation_editor;
+    
+    g_object_disconnect(G_OBJECT(automation_editor),
+			"any_signal::machine-changed",
+			G_CALLBACK(ags_ramp_acceleration_dialog_machine_changed_callback),
+			ramp_acceleration_dialog,
+			NULL);
+  }
 }
 
 void
@@ -481,9 +530,9 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
 {
   AgsRampAccelerationDialog *ramp_acceleration_dialog;
   AgsWindow *window;
-  AgsAutomationEditor *automation_editor;
   AgsMachine *machine;
   AgsNotebook *notebook;
+  AgsAutomationEdit *focused_automation_edit;
 
   AgsAudio *audio;
   AgsAutomation *current;
@@ -491,6 +540,8 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
 
   AgsTimestamp *timestamp;
 
+  AgsApplicationContext *application_context;
+
   GList *start_list_automation, *list_automation;
   GList *list_acceleration, *list_acceleration_start;
 
@@ -498,6 +549,7 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   
   GType channel_type;
 
+  gboolean use_composite_editor;
   gdouble gui_y;
   gdouble tact;
   
@@ -518,32 +570,59 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   
   ramp_acceleration_dialog = AGS_RAMP_ACCELERATION_DIALOG(applicable);
 
-  window = (AgsWindow *) ramp_acceleration_dialog->main_window;
-  automation_editor = window->automation_window->automation_editor;
+  /* application context */
+  application_context = ags_application_context_get_instance();
 
-  machine = automation_editor->selected_machine;
+  use_composite_editor = ags_ui_provider_use_composite_editor(AGS_UI_PROVIDER(application_context));
 
-  if(machine == NULL ||
-     automation_editor->focused_automation_edit == NULL){
-    return;
-  }
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+
+  machine = NULL;
 
-  specifier = gtk_combo_box_text_get_active_text(ramp_acceleration_dialog->port);
   notebook = NULL;
 
   channel_type = G_TYPE_NONE;
   
-  if(automation_editor->focused_automation_edit->channel_type == G_TYPE_NONE){
-    notebook = NULL;
-    channel_type = G_TYPE_NONE;
-  }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_OUTPUT){
-    notebook = automation_editor->output_notebook;
-    channel_type = AGS_TYPE_OUTPUT;
-  }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_INPUT){
-    notebook = automation_editor->input_notebook;
-    channel_type = AGS_TYPE_INPUT;
+  if(use_composite_editor){
+    AgsCompositeEditor *composite_editor;
+    
+    composite_editor = window->composite_editor;
+
+    machine = composite_editor->selected_machine;
+
+    focused_automation_edit = composite_editor->automation_edit->focused_edit;
+    
+    notebook = composite_editor->automation_edit->channel_selector;
+
+    channel_type = AGS_AUTOMATION_EDIT(composite_editor->automation_edit->focused_edit)->channel_type;
+  }else{
+    AgsAutomationEditor *automation_editor;
+    
+    automation_editor = window->automation_window->automation_editor;
+
+    machine = automation_editor->selected_machine;
+
+    focused_automation_edit = automation_editor->focused_automation_edit;
+    
+    if(automation_editor->focused_automation_edit->channel_type == G_TYPE_NONE){
+      notebook = NULL;
+      channel_type = G_TYPE_NONE;
+    }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_OUTPUT){
+      notebook = automation_editor->output_notebook;
+      channel_type = AGS_TYPE_OUTPUT;
+    }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_INPUT){
+      notebook = automation_editor->input_notebook;
+      channel_type = AGS_TYPE_INPUT;
+    }
   }
   
+  if(machine == NULL ||
+     focused_automation_edit == NULL){
+    return;
+  }
+
+  specifier = gtk_combo_box_text_get_active_text(ramp_acceleration_dialog->port);
+  
   audio = machine->audio;
 
   /* get some values */
@@ -987,27 +1066,47 @@ void
 ags_ramp_acceleration_dialog_reset(AgsApplicable *applicable)
 {
   AgsWindow *window;
-  AgsAutomationEditor *automation_editor;
   AgsMachine *machine;
   AgsRampAccelerationDialog *ramp_acceleration_dialog;
 
   AgsAudio *audio;
   AgsChannel *start_channel;
   AgsChannel *channel, *next_channel;
+
+  AgsApplicationContext *application_context;
   
   GList *start_port, *port;
 
   gchar **collected_specifier;
 
+  gboolean use_composite_editor;
   guint length;
 
   ramp_acceleration_dialog = AGS_RAMP_ACCELERATION_DIALOG(applicable);
 
-  window = AGS_WINDOW(ramp_acceleration_dialog->main_window);
-  automation_editor = window->automation_window->automation_editor;
+  /* application context */
+  application_context = ags_application_context_get_instance();
 
-  machine = automation_editor->selected_machine;
+  use_composite_editor = ags_ui_provider_use_composite_editor(AGS_UI_PROVIDER(application_context));
+  
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
+  machine = NULL;
+
+  if(use_composite_editor){
+    AgsCompositeEditor *composite_editor;
+    
+    composite_editor = window->composite_editor;
+
+    machine = composite_editor->selected_machine;
+  }else{
+    AgsAutomationEditor *automation_editor;
+    
+    automation_editor = window->automation_window->automation_editor;
+
+    machine = automation_editor->selected_machine;
+  }
+  
   gtk_list_store_clear(GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(ramp_acceleration_dialog->port))));
   
   if(machine == NULL){
